"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useForm = void 0;

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _immutable = require("immutable");

var _Form = require("./Form");

var _fields = require("./fields");

/**
 *
 * @param  param0 { import("../form").IFormProps }
 */
var useForm = function useForm(_ref) {
  var fields = _ref.fields,
      submit = _ref.submit,
      validate = _ref.validate,
      _ref$initialValues = _ref.initialValues,
      initialValues = _ref$initialValues === void 0 ? (0, _immutable.Map)() : _ref$initialValues;
  var fieldData = fields.reduce(function (acc, f) {
    if (!f.name) throw new Error('name is required on field');
    var initialValue = initialValues.get(f.name);

    switch (f.type) {
      case 'select':
        acc[f.name] = (0, _fields.useSelectField)(f, initialValue);
        break;

      case 'boolean':
        acc[f.name] = (0, _fields.useBooleanField)(f, initialValue);
        break;

      case 'number':
        acc[f.name] = (0, _fields.useNumberField)(f, initialValue);
        break;

      case 'text':
      default:
        acc[f.name] = (0, _fields.useTextField)(f, initialValue);
        break;
    }

    return acc;
  }, {});

  var tryValidateForm = function tryValidateForm() {
    if (validate) {
      var values = getFieldValues(fieldData);
      return validate(values);
    }

    return {};
  };

  var trySubmitForm = function trySubmitForm() {
    var isFormValid = true;
    var formResults = tryValidateForm();
    var values = Object.entries(fieldData).reduce(function (acc, _ref2) {
      var _ref3 = (0, _slicedToArray2.default)(_ref2, 2),
          key = _ref3[0],
          v = _ref3[1];

      acc[key] = v.props.value;

      if (formResults[key]) {
        v.setValidationResult({
          error: true,
          helperText: formResults[key]
        });
        isFormValid = false;
      }

      var isFieldValid = v.validate();
      isFormValid = isFormValid && isFieldValid;
      return acc;
    }, initialValues.toJS());

    if (isFormValid) {
      submit(values);
    }
  };

  var setValue = function setValue(fieldName, value) {
    fieldData[fieldName].setValue(value);
  };

  return (0, _objectSpread2.default)({}, getFieldProps(fieldData), {
    setValue: setValue,
    submit: trySubmitForm,
    Form: _Form.Form
  });
};

exports.useForm = useForm;

var getFieldValues = function getFieldValues(fieldData) {
  return Object.entries(fieldData).reduce(function (acc, _ref4) {
    var _ref5 = (0, _slicedToArray2.default)(_ref4, 2),
        k = _ref5[0],
        v = _ref5[1];

    acc[k] = v.props.value;
    return acc;
  }, {});
};

var getFieldProps = function getFieldProps(fieldData) {
  return Object.entries(fieldData).reduce(function (acc, _ref6) {
    var _ref7 = (0, _slicedToArray2.default)(_ref6, 2),
        k = _ref7[0],
        v = _ref7[1];

    acc[k] = v.props;
    return acc;
  }, {});
};