"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useFormField = void 0;

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _react = require("react");

var _formatLabel = require("./formatLabel");

/**
 * @param  args { import(".").IFormFieldArgs}
 */
var useFormField = function useFormField(initialValue) {
  var args = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var requiredMessage = args.requiredMessage || 'Required';

  var _useState = (0, _react.useState)({
    value: initialValue,
    error: false,
    helperText: args.helperText,
    pristine: true,
    touched: false
  }),
      _useState2 = (0, _slicedToArray2.default)(_useState, 2),
      state = _useState2[0],
      setState = _useState2[1];

  var tryValidate = function tryValidate(value, touched) {
    var result;

    if (value && args.validate) {
      result = args.validate(value, args.name);
    }

    if (!Boolean(result) && !args.optional && touched && value === '') {
      result = requiredMessage;
    }

    return touched ? {
      error: Boolean(result),
      helperText: result
    } : {
      error: state.error,
      helperText: state.helperText
    };
  };

  var setValue = function setValue(updatedValue) {
    setState((0, _objectSpread2.default)({}, state, {
      value: updatedValue,
      pristine: updatedValue === initialValue
    }, tryValidate(updatedValue, state.touched)));
  };

  var handleChange = function handleChange(_ref) {
    var target = _ref.target;
    var value = args.valueFromTarget ? args.valueFromTarget(target) : target.value;
    var coercedValue = args.normalize ? args.normalize(value) : value;
    setValue(coercedValue);
  };

  var onBlur = function onBlur() {
    setState((0, _objectSpread2.default)({}, state, {
      touched: true
    }, tryValidate(state.value, true)));
  };

  var onFocus = function onFocus() {};

  var setValidationResult = function setValidationResult(result) {
    setState((0, _objectSpread2.default)({}, state, result));
  };

  var validate = function validate() {
    var result = tryValidate(state.value, true);

    if (result.error) {
      setValidationResult(result);
      return false;
    }

    return true;
  };

  return {
    props: {
      error: state.error,
      helperText: state.helperText,
      label: (0, _formatLabel.formatLabel)(args.label, args.optional),
      value: state.value,
      // handlers
      onBlur: onBlur,
      onChange: handleChange,
      onFocus: onFocus
    },
    setValidationResult: setValidationResult,
    setValue: setValue,
    validate: validate
  };
};

exports.useFormField = useFormField;